package com.zd.laboratory.mapper;

import java.util.List;
import java.util.Map;

import com.zd.laboratory.domain.LabCheckRecordDetails;
import com.zd.laboratory.domain.vo.LabCheckMachineMsgDetailVo;
import com.zd.laboratory.domain.vo.LabCheckMachineMsgVo;
import com.zd.laboratory.domain.vo.LabCheckRecordDetailsVO;
import com.zd.laboratory.domain.vo.LabCheckRecordVO;

/**
 * 安全检查隐患表Mapper接口
 *
 * @author zd
 * @date 2021-12-30
 */
public interface LabCheckRecordDetailsMapper {
    /**
     * 查询安全检查隐患表
     *
     * @param id 安全检查隐患表主键
     * @return 安全检查隐患表
     */
    public LabCheckRecordDetails selectLabCheckRecordDetailsById(Long id);

    /**
     * 查询安全检查隐患表列表
     *
     * @param labCheckRecordDetails 安全检查隐患表
     * @return 安全检查隐患表集合
     */
    public List<LabCheckRecordDetails> selectLabCheckRecordDetailsList(LabCheckRecordDetails labCheckRecordDetails);

    /**
     * 查询安全检查隐患表列表
     *
     * @param labCheckRecordDetailsVo 安全检查隐患表
     * @return 安全检查隐患表集合
     */
    public List<LabCheckRecordDetailsVO> selectLabCheckRecordDetailsListVo(LabCheckRecordDetailsVO labCheckRecordDetailsVo);

    /**
     * 新增安全检查隐患表
     *
     * @param labCheckRecordDetails 安全检查隐患表
     * @return 结果
     */
    public int insertLabCheckRecordDetails(LabCheckRecordDetails labCheckRecordDetails);

    /**
     * 修改安全检查隐患表
     *
     * @param labCheckRecordDetails 安全检查隐患表
     * @return 结果
     */
    public int updateLabCheckRecordDetails(LabCheckRecordDetails labCheckRecordDetails);

    /**
     * 删除安全检查隐患表
     *
     * @param id 安全检查隐患表主键
     * @return 结果
     */
    public int deleteLabCheckRecordDetailsById(Long id);

    /**
     * 批量删除安全检查隐患表
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabCheckRecordDetailsByIds(Long[] ids);

    /***
     * 根据检查项id查询集合
     * @param jcxId
     * @return
     */
    public List<LabCheckRecordDetails> selectListByJcxId(String jcxId);

    /**
     * 大屏安全检查列表
     * @param labCheckRecordDetailsVo
     * @return
     */
    public List<LabCheckRecordDetailsVO> selectLabCheckRecordListVoIndex(LabCheckRecordDetailsVO labCheckRecordDetailsVo);

    /**
     * 大屏安全检查列表安全隐患项统计
     * @param labCheckRecordDetailsVo
     * @return
     */
    public LabCheckRecordDetailsVO selectLabCheckRecordCountIndex(LabCheckRecordDetailsVO labCheckRecordDetailsVo);

    /***
     * 大屏安全检查批次列表 详情跳转
     * @param labCheckRecordDetailsVo
     * @return
     */
    public List<LabCheckRecordDetailsVO> selectLabCheckRecordIndexDetals(LabCheckRecordDetailsVO labCheckRecordDetailsVo);

    /****
     * 大屏安全检查历史遗留问题总数查询
     * @param labCheckRecordDetailsVo
     * @return
     */
    public LabCheckRecordDetailsVO selectLabCheckRecordHistoryQuestionCount(LabCheckRecordDetailsVO labCheckRecordDetailsVo);

    /***
     * 待整改列表
     * @param labCheckRecordDetailsVo
     * @return
     */
    public List<LabCheckRecordDetailsVO> selectLabCheckRecordDzg(LabCheckRecordDetailsVO labCheckRecordDetailsVo);

    /***
     * 问题整改列表
     * @param labCheckRecordDetailsVo
     * @return
     */
    public List<LabCheckRecordDetailsVO> selectLabCheckRecordWtzg(LabCheckRecordDetailsVO labCheckRecordDetailsVo);

    /***
     * 隐患项 各个状态汇总
     * @param labCheckRecordVo
     * @return
     */
    public List<Map<String, Object>> selectDetailsStatusList(LabCheckRecordVO labCheckRecordVo);

    List<LabCheckMachineMsgDetailVo> selectCheckMsgDetail(Long checkId);
}
